Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1349)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java

Issue 1953543002: Rename WebAPK related classes to be of the format *WebApk*.java (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java b/chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java
index 5932b6f8a51fae50855bb2b7b49598192b7ae372..8ca414af6aff7e22ce35fda87dc9dd3f1e9e5721 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/tab/InterceptNavigationDelegateImpl.java
@@ -20,7 +20,7 @@ import org.chromium.content_public.browser.NavigationController;
import org.chromium.content_public.browser.WebContents;
import org.chromium.content_public.common.ConsoleMessageLevel;
import org.chromium.minting.lib.client.NavigationClient;
-import org.chromium.minting.lib.client.WebAPKValidator;
+import org.chromium.minting.lib.client.WebApkValidator;
/**
* Class that controls navigations and allows to intercept them. It is used on Android to 'convert'
@@ -256,10 +256,10 @@ public class InterceptNavigationDelegateImpl implements InterceptNavigationDeleg
private void onOverrideUrlLoadingAndLaunchIntentToMintedAPK(String url) {
onOverrideUrlLoadingAndLaunchIntent();
// {@link WebAPKValidator#queryWebAPKPackage()} is expensive. We should not be calling it
// multiple times per navigation.
String webAPKPackageName =
- WebAPKValidator.queryWebAPKPackage(mTab.getApplicationContext(), url);
+ WebApkValidator.queryWebAPKPackage(mTab.getApplicationContext(), url);
Intent intent = NavigationClient.createIntentToLaunchWebAPK(webAPKPackageName,
mTab.getActivity().getPackageName(), url);
mTab.getActivity().startActivity(intent);
@@ -256,10 +256,10 @@ public class InterceptNavigationDelegateImpl implements InterceptNavigationDeleg
private void onOverrideUrlLoadingAndLaunchIntentToMintedAPK(String url) {
onOverrideUrlLoadingAndLaunchIntent();
- // {@link WebAPKValidator#queryWebAPKPackage()} is expensive. We should not be calling it
+ // {@link WebApkValidator#queryWebAPKPackage()} is expensive. We should not be calling it
// multiple times per navigation.
String webAPKPackageName =

Powered by Google App Engine
This is Rietveld 408576698